IconTreeShaker class

A class that wraps the functionality of the const finder package and the font subset utility to tree shake unused icons from fonts.

Constructors

IconTreeShaker({required File appDill, required File dart, required File constFinder, required File fontSubset, required List<FontAsset> fonts, required bool isWeb})
Creates a wrapper for icon font subsetting.

Properties

appDill File
final
constFinder File
final
dart File
final
fonts List<FontAsset>
final
fontSubset File
final
hashCode int
The hash code for this object.
no setterinherited
isWeb bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getSubsetSummaryMessage(File inputFont, File outputFont) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
subsetFont({required FontAsset font, required String outputPath}) Future<FontAsset?>
Calls font-subset, which transforms the font to a subsetted version at outputPath.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

kTtfMimeTypes → const Set<String>
The MIME types for supported font sets.