IconTreeShaker class
A class that wraps the functionality of the const finder package and the font subset utility to tree shake unused icons from fonts.
Constructors
Properties
Methods
-
getSubsetSummaryMessage(
File inputFont, File outputFont) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
subsetFont(
{required FontAsset font, required String outputPath}) → Future< FontAsset?> -
Calls font-subset, which transforms the
fontto a subsetted version atoutputPath. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
kTtfMimeTypes
→ const Set<
String> - The MIME types for supported font sets.